Module convert

Module convert 

Functions

convert_type_expr
Convert an AST type expression into the internal Type representation.
convert_type_expr_with_env
Convert an AST type expression, resolving type aliases from the environment.
convert_type_expr_with_params
Convert an AST type expression, recognizing type parameters from the given list.