TypeEnv

Struct TypeEnv 

pub struct TypeEnv { /* private fields */ }
Type environment — tracks variable types across scopes.

Implementations

Source

impl TypeEnv

pub fn new() -> Self

pub fn scope_depth(&self) -> u32

pub fn push_scope(&mut self)

pub fn pop_scope(&mut self)

pub fn define(&mut self, name: String, ty: Type)

pub fn lookup(&self, name: &str) -> Option<&Type>

pub fn define_fn(&mut self, name: String, sig: FnSig)

pub fn lookup_fn(&self, name: &str) -> Option<&FnSig>

pub fn define_struct(&mut self, name: String, fields: Vec<(String, Type)>)

pub fn lookup_struct(&self, name: &str) -> Option<&Vec<(String, Type)>>

pub fn define_enum(&mut self, name: String, variants: Vec<(String, Vec<Type>)>)

pub fn lookup_enum(&self, name: &str) -> Option<&Vec<(String, Vec<Type>)>>

pub fn fresh_var(&mut self) -> Type

pub fn define_trait(&mut self, name: String, info: TraitInfo)

pub fn lookup_trait(&self, name: &str) -> Option<&TraitInfo>

pub fn register_type_alias( &mut self, name: String, type_params: Vec<String>, value: TypeExpr, )

pub fn lookup_type_alias(&self, name: &str) -> Option<&(Vec<String>, TypeExpr)>

pub fn is_resolving_alias(&self, name: &str) -> bool

Check if an alias is currently being resolved (cycle detection).

pub fn start_resolving_alias(&mut self, name: String)

Mark an alias as being resolved.

pub fn stop_resolving_alias(&mut self, name: &str)

Unmark an alias after resolution.

pub fn register_sensitive_field( &mut self, type_name: String, field_name: String, annotation: String, )

Register a sensitive field annotation.

pub fn is_field_sensitive(&self, type_name: &str, field_name: &str) -> bool

Check if a field is annotated as sensitive.

pub fn get_field_annotations( &self, type_name: &str, ) -> Option<&Vec<(String, String)>>

Get sensitive annotations for a type’s field.

pub fn register_trait_impl( &mut self, trait_name: String, type_name: String, method_names: Vec<String>, )

pub fn lookup_trait_impl( &self, trait_name: &str, type_name: &str, ) -> Option<&Vec<String>>

pub fn type_satisfies_trait(&self, ty: &Type, trait_name: &str) -> bool

Check if a type satisfies a trait bound (including built-in trait hierarchy).